@@ -317,7 +317,7 @@ static void init_config (void)
 
 #ifdef PLUGIN_NAME
 
-void init_plugin (void)
+void init_plugin (GtkWidget *)
 {
     setlocale (LC_ALL, "");
     bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
@@ -483,6 +483,7 @@ static void backup_config_files (void)
     backup_file (".config/libfm/libfm.conf");
     backup_file (".config/gtk-3.0/gtk.css");
     backup_file (".config/qt5ct/qt5ct.conf");
+    backup_file (".config/qt6ct/qt6ct.conf");
     backup_file (".config/xsettingsd/xsettingsd.conf");
     backup_file (".config/wayfire.ini");
     backup_file (".config/labwc/themerc-override");
@@ -561,6 +562,7 @@ static int restore_config_files (void)
     if (restore_file (".config/libfm/libfm.conf")) changed = 1;
     if (restore_file (".config/gtk-3.0/gtk.css")) changed = 1;
     if (restore_file (".config/qt5ct/qt5ct.conf")) changed = 1;
+    if (restore_file (".config/qt6ct/qt6ct.conf")) changed = 1;
     if (restore_file (".config/xsettingsd/xsettingsd.conf")) changed = 1;
     if (restore_file (".config/wayfire.ini")) changed = 1;
     if (restore_file (".config/labwc/themerc-override")) changed = 1;
