@@ -200,6 +200,12 @@ static void load_obconf_settings (void)
 {
     char *user_config_file;
     int val;
+    xmlChar *width;
+
+    xmlDocPtr xDoc;
+    xmlXPathContextPtr xpathCtx;
+    xmlXPathObjectPtr xpathObj;
+    xmlNodePtr node;
 
     DEFAULT (handle_width);
 
@@ -213,23 +219,25 @@ static void load_obconf_settings (void)
     // read in data from XML file
     xmlInitParser ();
     LIBXML_TEST_VERSION
-    xmlDocPtr xDoc = xmlParseFile (user_config_file);
+    xDoc = xmlParseFile (user_config_file);
     if (xDoc == NULL)
     {
         g_free (user_config_file);
         return;
     }
+    xpathCtx = xmlXPathNewContext (xDoc);
 
-    xmlXPathContextPtr xpathCtx = xmlXPathNewContext (xDoc);
-    xmlXPathObjectPtr xpathObj = xmlXPathEvalExpression ((xmlChar *) "/*[local-name()='openbox_config']/*[local-name()='theme']/*[local-name()='invHandleWidth']", xpathCtx);
-    xmlNode *node = xpathObj->nodesetval->nodeTab[0];
+    xpathObj = xmlXPathEvalExpression ((xmlChar *) "/*[local-name()='openbox_config']/*[local-name()='theme']/*[local-name()='invHandleWidth']", xpathCtx);
+    node = xpathObj->nodesetval->nodeTab[0];
     if (node)
     {
-         if (sscanf ((const char *) xmlNodeGetContent (node), "%d", &val) == 1 && val > 0) cur_conf.handle_width = val;
+        width = xmlNodeGetContent (node);
+        if (sscanf ((const char *) width, "%d", &val) == 1 && val > 0) cur_conf.handle_width = val;
+        xmlFree (width);
     }
+    xmlXPathFreeObject (xpathObj);
 
     // cleanup XML
-    xmlXPathFreeObject (xpathObj);
     xmlXPathFreeContext (xpathCtx);
     xmlFreeDoc (xDoc);
     xmlCleanupParser ();
@@ -388,15 +396,15 @@ static void load_gtk3_settings (void)
 
 static void save_wm_settings (void)
 {
-    char *user_config_file, *theme, *font, *cptr;
+    char *user_config_file, *cptr;
     int count, size;
-    const gchar *weight = NULL, *style = NULL;
+    const gchar *font = NULL, *weight = NULL, *style = NULL;
     char buf[10];
 
     xmlDocPtr xDoc;
-    xmlNodePtr root, cur_node, node;
-    xmlXPathObjectPtr xpathObj;
     xmlXPathContextPtr xpathCtx;
+    xmlXPathObjectPtr xpathObj;
+    xmlNodePtr root, cur_node, node;
 
     if (wm == WM_LABWC) user_config_file = labwc_file ();
     else if (wm == WM_OPENBOX) user_config_file = openbox_file ();
@@ -406,7 +414,9 @@ static void save_wm_settings (void)
 
     // set the font description variables for XML from the font name
     PangoFontDescription *pfd = pango_font_description_from_string (cur_conf.desktop_font);
+    font = pango_font_description_get_family (pfd);
     size = pango_font_description_get_size (pfd) / (pango_font_description_get_size_is_absolute (pfd) ? 1 : PANGO_SCALE);
+    sprintf (buf, "%d", size);
     PangoWeight pweight = pango_font_description_get_weight (pfd);
     PangoStyle pstyle = pango_font_description_get_style (pfd);
 
@@ -460,15 +470,6 @@ static void save_wm_settings (void)
                                             break;
         }
     }
-    pango_font_description_unset_fields (pfd, PANGO_FONT_MASK_WEIGHT);
-    pango_font_description_unset_fields (pfd, PANGO_FONT_MASK_STYLE);
-    pango_font_description_unset_fields (pfd, PANGO_FONT_MASK_STRETCH);
-
-    // by this point, Bold and Italic flags will be missing from the font description, so just remove the size...
-    font = g_strdup (pango_font_description_to_string (pfd));
-    cptr = font + strlen (font) - 1;
-    while (*cptr >= '0' && *cptr <= '9') cptr--;
-    *cptr = 0;
 
     // read in data from XML file
     xmlInitParser ();
@@ -508,7 +509,6 @@ static void save_wm_settings (void)
             cur_node = xmlNewChild (xpathObj->nodesetval->nodeTab[0], NULL, XC ("font"), NULL);
 
             xmlSetProp (cur_node, XC ("place"), count == 0 ? XC ("ActiveWindow") : XC ("InactiveWindow"));
-            sprintf (buf, "%d", size);
             xmlNewChild (cur_node, NULL, XC ("name"), XC (font));
             xmlNewChild (cur_node, NULL, XC ("size"), XC (buf));
             xmlNewChild (cur_node, NULL, XC ("weight"), XC (weight));
@@ -520,12 +520,10 @@ static void save_wm_settings (void)
         for (count = 0; count < xpathObj->nodesetval->nodeNr; count++)
         {
             node = xpathObj->nodesetval->nodeTab[count];
-            cur_node = NULL;
             for (cur_node = node->children; cur_node; cur_node = cur_node->next)
             {
                 if (cur_node->type == XML_ELEMENT_NODE)
                 {
-                    sprintf (buf, "%d", size);
                     if (!xmlStrcmp (cur_node->name, XC ("name"))) xmlNodeSetContent (cur_node, XC (font));
                     if (!xmlStrcmp (cur_node->name, XC ("size"))) xmlNodeSetContent (cur_node, XC (buf));
                     if (!xmlStrcmp (cur_node->name, XC ("weight"))) xmlNodeSetContent (cur_node, XC (weight));
@@ -535,22 +533,23 @@ static void save_wm_settings (void)
         }
     }
     xmlXPathFreeObject (xpathObj);
+    pango_font_description_free (pfd);
 
-    theme = g_strdup_printf ("%s%s", theme_name (cur_conf.darkmode), cur_conf.scrollbar_width >= 17 ? "_l" : "");
+    cptr = g_strdup_printf ("%s%s", theme_name (cur_conf.darkmode), cur_conf.scrollbar_width >= 17 ? "_l" : "");
     xpathObj = xmlXPathEvalExpression (XC ("/*[local-name()='openbox_config']/*[local-name()='theme']/*[local-name()='name']"), xpathCtx);
     if (xmlXPathNodeSetIsEmpty (xpathObj->nodesetval))
     {
         xmlXPathFreeObject (xpathObj);
         xpathObj = xmlXPathEvalExpression (XC ("/*[local-name()='openbox_config']/*[local-name()='theme']"), xpathCtx);
         cur_node = xpathObj->nodesetval->nodeTab[0];
-        xmlNewChild (cur_node, NULL, XC ("name"), XC (theme));
+        xmlNewChild (cur_node, NULL, XC ("name"), XC (cptr));
     }
     else
     {
         cur_node = xpathObj->nodesetval->nodeTab[0];
-        xmlNodeSetContent (cur_node, XC (theme));
+        xmlNodeSetContent (cur_node, XC (cptr));
     }
-    g_free (theme);
+    g_free (cptr);
 
     if (wm == WM_LABWC) save_labwc_to_settings ();
     else
@@ -569,6 +568,7 @@ static void save_wm_settings (void)
             cur_node = xpathObj->nodesetval->nodeTab[0];
             xmlNodeSetContent (cur_node, XC (buf));
         }
+        xmlXPathFreeObject (xpathObj);
 
         cptr = rgba_to_gdk_color_string (&cur_conf.theme_colour[cur_conf.darkmode]);
         xpathObj = xmlXPathEvalExpression (XC ("/*[local-name()='openbox_config']/*[local-name()='theme']/*[local-name()='titleColor']"), xpathCtx);
@@ -584,6 +584,7 @@ static void save_wm_settings (void)
             cur_node = xpathObj->nodesetval->nodeTab[0];
             xmlNodeSetContent (cur_node, XC (cptr));
         }
+        xmlXPathFreeObject (xpathObj);
         g_free (cptr);
 
         cptr = rgba_to_gdk_color_string (&cur_conf.themetext_colour[cur_conf.darkmode]);
@@ -600,18 +601,16 @@ static void save_wm_settings (void)
             cur_node = xpathObj->nodesetval->nodeTab[0];
             xmlNodeSetContent (cur_node, XC (cptr));
         }
+        xmlXPathFreeObject (xpathObj);
         g_free (cptr);
     }
 
     // cleanup XML
-    xmlXPathFreeObject (xpathObj);
     xmlXPathFreeContext (xpathCtx);
     xmlSaveFile (user_config_file, xDoc);
     xmlFreeDoc (xDoc);
     xmlCleanupParser ();
 
-    pango_font_description_free (pfd);
-    g_free (font);
     g_free (user_config_file);
 }
 
